Module cdoc_parser::ast::visitor

source ·

Traits

  • Implements the visitor pattern for the cdoc Ast type. Blanket implementations are provided so implementors only have to implement the methods they need to modify.